Class: Shortwave::Facade::Group
- Defined in:
- lib/shortwave/facade/lastfm.rb
Instance Attribute Summary
Attributes inherited from Remote
Instance Method Summary collapse
-
#members(group) ⇒ Object
Get a list of members for this group.
-
#weekly_album_chart(group, options = {}) ⇒ Object
Get an album chart for a group, for a given date range.
-
#weekly_artist_chart(group, options = {}) ⇒ Object
Get an artist chart for a group, for a given date range.
-
#weekly_chart_list(group) ⇒ Object
Get a list of available charts for this group, expressed as date ranges which can be sent to the chart services.
-
#weekly_track_chart(group, options = {}) ⇒ Object
Get a track chart for a group, for a given date range.
Methods inherited from Remote
Constructor Details
This class inherits a constructor from Shortwave::Facade::Remote
Instance Method Details
#members(group) ⇒ Object
Get a list of members for this group.
groupThe group name to fetch the members of.
304 305 306 |
# File 'lib/shortwave/facade/lastfm.rb', line 304 def members(group) get(:standard, {:method => "group.getMembers", :group => group}) end |
#weekly_album_chart(group, options = {}) ⇒ Object
Get an album chart for a group, for a given date range. If no date range is supplied, it will return the most recent album chart for this group.
groupGroup name
Options
fromThe date at which the chart should start from. See Group.getWeeklyChartList for more.
toThe date at which the chart should end on. See Group.getWeeklyChartList for more.
322 323 324 |
# File 'lib/shortwave/facade/lastfm.rb', line 322 def weekly_album_chart(group, ={}) get(:standard, {:method => "group.getWeeklyAlbumChart", :group => group}.merge()) end |
#weekly_artist_chart(group, options = {}) ⇒ Object
Get an artist chart for a group, for a given date range. If no date range is supplied, it will return the most recent album chart for this group.
groupThe last.fm group name to fetch the charts of.
Options
fromThe date at which the chart should start from. See Group.getWeeklyChartList for more.
toThe date at which the chart should end on. See Group.getWeeklyChartList for more.
344 345 346 |
# File 'lib/shortwave/facade/lastfm.rb', line 344 def weekly_artist_chart(group, ={}) get(:standard, {:method => "group.getWeeklyArtistChart", :group => group}.merge()) end |
#weekly_chart_list(group) ⇒ Object
Get a list of available charts for this group, expressed as date ranges which can be sent to the chart services.
groupThe last.fm group name to fetch the charts list for.
311 312 313 |
# File 'lib/shortwave/facade/lastfm.rb', line 311 def weekly_chart_list(group) get(:standard, {:method => "group.getWeeklyChartList", :group => group}) end |
#weekly_track_chart(group, options = {}) ⇒ Object
Get a track chart for a group, for a given date range. If no date range is supplied, it will return the most recent album chart for this group.
groupThe last.fm group name to fetch the charts of.
Options
fromThe date at which the chart should start from. See Group.getWeeklyChartList for more.
toThe date at which the chart should end on. See Group.getWeeklyChartList for more.
333 334 335 |
# File 'lib/shortwave/facade/lastfm.rb', line 333 def weekly_track_chart(group, ={}) get(:standard, {:method => "group.getWeeklyTrackChart", :group => group}.merge()) end |