Class: Shortwave::Facade::Venue
- Defined in:
- lib/shortwave/facade/lastfm.rb
Instance Attribute Summary
Attributes inherited from Remote
Instance Method Summary collapse
-
#events(venue) ⇒ Object
Get a list of upcoming events at this venue.
-
#past_events(venue, options = {}) ⇒ Object
Get a paginated list of all the events held at this venue in the past.
-
#search(venue, options = {}) ⇒ Object
Search for a venue by venue name.
Methods inherited from Remote
Constructor Details
This class inherits a constructor from Shortwave::Facade::Remote
Instance Method Details
#events(venue) ⇒ Object
Get a list of upcoming events at this venue.
venueThe id for the venue you would like to fetch event listings for.
485 486 487 |
# File 'lib/shortwave/facade/lastfm.rb', line 485 def events(venue) get(:standard, {:method => "venue.getEvents", :venue => venue}) end |
#past_events(venue, options = {}) ⇒ Object
Get a paginated list of all the events held at this venue in the past.
venueThe id for the venue you would like to fetch event listings for.
Options
pageThe page of results to return.
limitThe maximum number of results to return.
478 479 480 |
# File 'lib/shortwave/facade/lastfm.rb', line 478 def past_events(venue, ={}) get(:standard, {:method => "venue.getPastEvents", :venue => venue}.merge()) end |
#search(venue, options = {}) ⇒ Object
Search for a venue by venue name
venueThe venue name you would like to search for.
Options
pageThe results page you would like to fetch
limitThe number of results to fetch per page. Defaults to 50.
countryFilter your results by country. Expressed as an ISO 3166-2 code.
497 498 499 |
# File 'lib/shortwave/facade/lastfm.rb', line 497 def search(venue, ={}) get(:standard, {:method => "venue.search", :venue => venue}.merge()) end |